@@ -9,7 +9,8 @@ from fmdt.api import (
     detect,
     visu,
     count,
-    detect_directory
+    detect_directory,
+    check
 )
 
 from fmdt.args import (
@@ -43,8 +44,12 @@ from fmdt.config import (
     load_gt12,
     load_gt6,
     load_config,
-    get_draco12,
-    get_draco6
+    listdir_draco12,
+    listdir_draco6,
+    listdir_window,
+    setdir_draco6,
+    setdir_draco12,
+    setdir_window
 )
 
 from fmdt.db import (
@@ -53,13 +58,14 @@ from fmdt.db import (
     load_in_videos,
     load_draco6,
     load_draco12,
-    load_window
+    load_window,
+    info as db_info
 )
 
 # from fmdt.truth import HumanDetection
 
 MAJOR_VERSION = 0
 MINOR_VERSION = 0
-PATCH         = 28
+PATCH         = 29
 
 VERSION = str(MAJOR_VERSION) + "." + str(MINOR_VERSION) + "." + str(PATCH)
